summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorEike Rathke <erack@redhat.com>2013-11-13 16:55:48 +0100
committerEike Rathke <erack@redhat.com>2013-11-13 17:15:59 +0100
commitdebe0835cad25931a934eb3e1f205d508e6498cd (patch)
treea80e0cc2f00c668e77f165e0289c65cc2338a1ab /include
parenta500ab2ee19a5221817c13fc8975c27fe4e92246 (diff)
introduced FormulaGrammar::GRAM_OOXML with FormulaLanguage::OOXML
FormulaLanguage::XL_ENGLISH is not OOXML, unconditionally using SymbolsEnglishXL with RID_STRLIST_FUNCTION_NAMES_ENGLISH_OOXML spoils the grammars of FormulaLanguage::XL_ENGLISH that are not OOXML. Change-Id: Id885d1c033cd15dc7b11c6490be3a98500027d37
Diffstat (limited to 'include')
-rw-r--r--include/formula/FormulaCompiler.hxx12
-rw-r--r--include/formula/grammar.hxx6
2 files changed, 13 insertions, 5 deletions
diff --git a/include/formula/grammar.hxx b/include/formula/grammar.hxx
index 34a0aa619302..e3f29de543e7 100644
--- a/include/formula/grammar.hxx
+++ b/include/formula/grammar.hxx
@@ -134,6 +134,11 @@ public:
((CONV_XL_OOX +
kConventionOffset) << kConventionShift) |
kEnglishBit,
+ /// Excel OOXML with Excel OOXML reference style.
+ GRAM_OOXML = ::com::sun::star::sheet::FormulaLanguage::OOXML |
+ ((CONV_XL_OOX +
+ kConventionOffset) << kConventionShift) |
+ kEnglishBit,
/// Central definition of the default grammar to be used.
GRAM_DEFAULT = GRAM_NATIVE_UI,
@@ -187,6 +192,7 @@ public:
case GRAM_ENGLISH_XL_A1 :
case GRAM_ENGLISH_XL_R1C1:
case GRAM_ENGLISH_XL_OOX :
+ case GRAM_OOXML :
return true;
default:
return extractFormulaLanguage( eGrammar) == GRAM_EXTERNAL;
diff --git a/include/formula/FormulaCompiler.hxx b/include/formula/FormulaCompiler.hxx
index e7ce9208b9c4..5ce3c2dc3b2b 100644
--- a/include/formula/FormulaCompiler.hxx
+++ b/include/formula/FormulaCompiler.hxx
@@ -333,6 +333,7 @@ private:
void InitSymbolsPODF() const; /// only SymbolsPODF, on demand
void InitSymbolsODFF() const; /// only SymbolsODFF, on demand
void InitSymbolsEnglishXL() const; /// only SymbolsEnglishXL, on demand
+ void InitSymbolsOOXML() const; /// only SymbolsOOXML, on demand
void loadSymbols(sal_uInt16 _nSymbols,FormulaGrammar::Grammar _eGrammar,NonConstOpCodeMapPtr& _xMap) const;
@@ -382,11 +383,12 @@ private:
};
- mutable NonConstOpCodeMapPtr mxSymbolsODFF; // ODFF symbols
- mutable NonConstOpCodeMapPtr mxSymbolsPODF; // ODF 1.1 symbols
- mutable NonConstOpCodeMapPtr mxSymbolsNative; // native symbols
- mutable NonConstOpCodeMapPtr mxSymbolsEnglish; // English symbols
- mutable NonConstOpCodeMapPtr mxSymbolsEnglishXL; // English Excel symbols (for VBA formula parsing)
+ mutable NonConstOpCodeMapPtr mxSymbolsODFF; // ODFF symbols
+ mutable NonConstOpCodeMapPtr mxSymbolsPODF; // ODF 1.1 symbols
+ mutable NonConstOpCodeMapPtr mxSymbolsNative; // native symbols
+ mutable NonConstOpCodeMapPtr mxSymbolsEnglish; // English symbols
+ mutable NonConstOpCodeMapPtr mxSymbolsEnglishXL; // English Excel symbols (for VBA formula parsing)
+ mutable NonConstOpCodeMapPtr mxSymbolsOOXML; // Excel OOXML symbols
};
// =============================================================================
} // formula